Macro route_by_rule
macro_rules! route_by_rule {
($response:expr, _ => $default:expr $(,)?) => { ... };
($response:expr, $rule:literal => $handler:expr, $($rest:tt)+) => { ... };
}Expand description
Routes parse logic based on the discovery rule name attached to a response.
This is a lightweight helper for rule-based crawling. The response is only consumed by the matched branch, so each branch may move it into a dedicated parse helper.